@@ -15,4 +15,4 @@ class TimePoint(BaseModel):
     fields: Dict[str, float]
 
     async def send(self):
-        await InfluxDBHub.send(self.dict())
+        await InfluxDBHub.send(self)
